Simple Test
------------

Ensure your device works with this simple test.

.. literalinclude:: ../examples/st7735r_simpletest.py
    :caption: examples/st7735r_simpletest.py
    :linenos:

128x160 Tests
--------------------

Examples for the 128x160

.. literalinclude:: ../examples/st7735r_128x160_simpletest.py
    :caption: examples/st7735r_128x160_simpletest.py
    :linenos:

.. literalinclude:: ../examples/st7735r_128x160_colored_labels.py
    :caption: examples/st7735r_128x160_colored_labels.py
    :linenos:

Minitft FeatherWing Test
-------------------------

Simple example for the minitft featherwing

.. literalinclude:: ../examples/st7735r_minitft_featherwing_simpletest.py
    :caption: examples/st7735r_minitft_featherwing_simpletest.py
    :linenos:

MiniTFT Test
------------

Simple example for the minitft

.. literalinclude:: ../examples/st7735r_minitft_simpletest.py
    :caption: examples/st7735r_minitft_simpletest.py
    :linenos:

Shield Buttons
--------------

Example for the shield buttons

.. literalinclude:: ../examples/st7735r_18tftshield_buttons.py
    :caption: examples/st7735r_18tftshield_buttons.py
    :linenos:
